==> goods-center-api-1.4-20160621.020110-5-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/PCGEditDto.java <==
/**
 * Project Name:goods-center-api
 * File Name:PCGEditDTO.java
 * Package Name:cn.com.duiba.goods.center.api.remoteservice.dto
 * Date:2016年5月26日下午2:23:00
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.goods.center.api.remoteservice.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * ClassName:PCGEditDTO <br/>
 * Function: 编辑商品时提供的DTO，只有这个DTO内部的属性才能编辑 <br/>
 * Date:     2016年5月26日 下午2:23:00 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public class PCGEditDto implements Serializable{


    private static final long serialVersionUID = 1L;

    private Long pcgId;
    
    private String title;
    
    private String name;
    
    private String subtitle;
    
    private Integer minPrice;
    
    private String usePrompt;
    
    private String buttonText;
    
    private Integer interestPrice;
    
    private String interestDesc;
    
    private String backgroundColor;
    
    private String iconImage;
    
    private String thumbnailImage;
    
    private String detailImage;
    
    private Date autoOffDate;
    /**
     * 每个用户最多兑换次数
     */
    private Integer limitPerConsumer;
    
    private String detail;//详情描述信息

    
    public Long getPcgId() {
        return pcgId;
    }

    
    public void setPcgId(Long pcgId) {
        this.pcgId = pcgId;
    }

    
    public String getTitle() {
        return title;
    }

    
    public void setTitle(String title) {
        this.title = title;
    }

    
    public String getName() {
        return name;
    }

    
    public void setName(String name) {
        this.name = name;
    }

    
    public String getSubtitle() {
        return subtitle;
    }

    
    public void setSubtitle(String subtitle) {
        this.subtitle = subtitle;
    }

    
    public Integer getMinPrice() {
        return minPrice;
    }

    
    public void setMinPrice(Integer minPrice) {
        this.minPrice = minPrice;
    }

    
    public String getUsePrompt() {
        return usePrompt;
    }

    
    public void setUsePrompt(String usePrompt) {
        this.usePrompt = usePrompt;
    }

    
    public String getButtonText() {
        return buttonText;
    }

    
    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    
    public Integer getInterestPrice() {
        return interestPrice;
    }

    
    public void setInterestPrice(Integer interestPrice) {
        this.interestPrice = interestPrice;
    }

    
    public String getInterestDesc() {
        return interestDesc;
    }

    
    public void setInterestDesc(String interestDesc) {
        this.interestDesc = interestDesc;
    }

    
    public String getBackgroundColor() {
        return backgroundColor;
    }

    
    public void setBackgroundColor(String backgroundColor) {
        this.backgroundColor = backgroundColor;
    }

    
    public String getIconImage() {
        return iconImage;
    }

    
    public void setIconImage(String iconImage) {
        this.iconImage = iconImage;
    }

    
    public String getThumbnailImage() {
        return thumbnailImage;
    }

    
    public void setThumbnailImage(String thumbnailImage) {
        this.thumbnailImage = thumbnailImage;
    }

    
    public String getDetailImage() {
        return detailImage;
    }

    
    public void setDetailImage(String detailImage) {
        this.detailImage = detailImage;
    }

    
    public Date getAutoOffDate() {
        return autoOffDate;
    }

    
    public void setAutoOffDate(Date autoOffDate) {
        this.autoOffDate = autoOffDate;
    }


    
    public String getDetail() {
        return detail;
    }


    
    public void setDetail(String detail) {
        this.detail = detail;
    }


    
    public Integer getLimitPerConsumer() {
        return limitPerConsumer;
    }


    
    public void setLimitPerConsumer(Integer limitPerConsumer) {
        this.limitPerConsumer = limitPerConsumer;
    }
    
}

==> goods-center-api-1.9.7-20170223.113330-1-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/PCGEditDto.java <==
/**
 * Project Name:goods-center-api
 * File Name:PCGEditDTO.java
 * Package Name:cn.com.duiba.goods.center.api.remoteservice.dto
 * Date:2016年5月26日下午2:23:00
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.goods.center.api.remoteservice.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * ClassName:PCGEditDTO <br/>
 * Function: 编辑商品时提供的DTO，只有这个DTO内部的属性才能编辑 <br/>
 * Date:     2016年5月26日 下午2:23:00 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public class PCGEditDto implements Serializable{


    private static final long serialVersionUID = 1L;

    private Long pcgId;
    
    private String title;
    
    private String name;
    
    private String subtitle;
    
    private Integer minPrice;
    
    private String usePrompt;
    
    private String buttonText;
    
    private String interestPrice;
    
    private String interestDesc;
    
    private String backgroundColor;
    
    private String iconImage;
    
    private String thumbnailImage;
    
    private String detailImage;
    
    private Date autoOffDate;
    /**
     * 每个用户最多兑换次数
     */
    private Integer limitPerConsumer;
    
    private String detail;//详情描述信息
    
    private Integer facePrice;

    private String tags;

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }

    public Long getPcgId() {
        return pcgId;
    }

    
    public void setPcgId(Long pcgId) {
        this.pcgId = pcgId;
    }

    
    public String getTitle() {
        return title;
    }

    
    public void setTitle(String title) {
        this.title = title;
    }

    
    public String getName() {
        return name;
    }

    
    public void setName(String name) {
        this.name = name;
    }

    
    public String getSubtitle() {
        return subtitle;
    }

    
    public void setSubtitle(String subtitle) {
        this.subtitle = subtitle;
    }

    
    public Integer getMinPrice() {
        return minPrice;
    }

    
    public void setMinPrice(Integer minPrice) {
        this.minPrice = minPrice;
    }

    
    public String getUsePrompt() {
        return usePrompt;
    }

    
    public void setUsePrompt(String usePrompt) {
        this.usePrompt = usePrompt;
    }

    
    public String getButtonText() {
        return buttonText;
    }

    
    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    
    public String getInterestPrice() {
        return interestPrice;
    }

    
    public void setInterestPrice(String interestPrice) {
        this.interestPrice = interestPrice;
    }

    
    public String getInterestDesc() {
        return interestDesc;
    }

    
    public void setInterestDesc(String interestDesc) {
        this.interestDesc = interestDesc;
    }

    
    public String getBackgroundColor() {
        return backgroundColor;
    }

    
    public void setBackgroundColor(String backgroundColor) {
        this.backgroundColor = backgroundColor;
    }

    
    public String getIconImage() {
        return iconImage;
    }

    
    public void setIconImage(String iconImage) {
        this.iconImage = iconImage;
    }

    
    public String getThumbnailImage() {
        return thumbnailImage;
    }

    
    public void setThumbnailImage(String thumbnailImage) {
        this.thumbnailImage = thumbnailImage;
    }

    
    public String getDetailImage() {
        return detailImage;
    }

    
    public void setDetailImage(String detailImage) {
        this.detailImage = detailImage;
    }

    
    public Date getAutoOffDate() {
        return autoOffDate;
    }

    
    public void setAutoOffDate(Date autoOffDate) {
        this.autoOffDate = autoOffDate;
    }


    
    public String getDetail() {
        return detail;
    }


    
    public void setDetail(String detail) {
        this.detail = detail;
    }


    
    public Integer getLimitPerConsumer() {
        return limitPerConsumer;
    }


    
    public void setLimitPerConsumer(Integer limitPerConsumer) {
        this.limitPerConsumer = limitPerConsumer;
    }


    
    public Integer getFacePrice() {
        return facePrice;
    }


    
    public void setFacePrice(Integer facePrice) {
        this.facePrice = facePrice;
    }
    
}
